* PROJECT:
* Jan Eeckhout, Roberto Pinheiro, Kurt Schmidheiny
* "Spatial Sorting"
* Forthcoming 2014 in the Journal of Political Economy
*
* FILE: 
* data.do
*
* DESCRIPTION:
* this file generates the data files and variables used for the empirical analysis 
* from various raw data sources
* also produces Tables 3, 4 and 5 in Appendix B
*
* VERSION: 
* Jan-13-2014

clear all
set mem 700m
set matsize 2500

* ------------------------------
* CBSA labels 
* ------------------------------

* DATA SOURCE:
* Missouri Census Data Center (MCDC)
*
* WEBLINK:
* http://mcdc.missouri.edu/websas/geocorr2k.html
*
* LOCAL FILE LOCATION:
* rawdata/cbsa.dta

* open raw data
use rawdata/cbsa.dta, clear
label variable cbsa "Core based Statistical Area CBSA, FIPS code, 2000 (Source: MCDC)"

* turn area names into labels
sort cbsa
count if ~missing(cbsa)
local obs = r(N)
label define cbsa 9999 "Non-metro"
forvalues i=1/`obs' {
	local code = cbsa[`i']
	local name = cbsaname[`i']
	capture label define cbsa `code' "`name'", add
}
label values cbsa cbsa

* save cbsa labels 
label save cbsa using temp/cbsalabel.do, replace

* ------------------------------
* PUMA to CBSA Correspondence 
* ------------------------------

* DATA SOURCE:
* Missouri Census Data Center (MCDC)
*
* WEBLINK:
* http://mcdc.missouri.edu/websas/geocorr2k.html
*
* LOCAL FILE LOCATION:
* rawdata/pumacbsa.dta

* open raw data
use rawdata/pumacbsa.dta, clear

* labels
rename puma5 puma
label variable state "State FIPS code [MCDC/Geocorr2K]"
label variable puma "Public Use Microdata Area, for 5% PUMS [MCDC/Geocorr2K]"
label variable cbsa "Core based statistical area, metropolitan and micropolitan [MCDC/Geocorr2K]"

* keep only main CBSA which corresponds to PUMA
bysort state puma: egen afactmax = max(afact)
keep if afact==afactmax
* keep only PUMA in which more than 33% of housing belongs to CBSA
drop if afact <= 0.33

* create unique PUMA identifier
* note: same PUMA code may be used in different states
generate statepuma = state*10000+puma
label variable statepuma "Unique PUMA identifier"

* save data
drop afact afactmax hus2k stab
sort state puma statepuma cbsa
save temp/puma.dta, replace

* ------------------------------
* NECTA to CBSA Correspondence 
* ------------------------------

* DATA SOURCE:
* Missouri Census Data Center (MCDC)
*
* WEBLINK:
* http://mcdc.missouri.edu/websas/geocorr2k.html
*
* LOCAL FILE LOCATION:
* rawdata/nectacbsa.dta 
*
* DESCRIPTION:
* New England city and town areas (NECTA) code
* to Core Based Statistical Area (CBSA) code correspondence

* open raw data
use "rawdata/nectacbsa.dta", clear

* find largest NECTA part corresponding to CBSA
drop if missing(necta)
drop if missing(cbsa)
bysort cbsa: egen afactmax = max(afact)
keep if afact==afactmax
drop afact afactmax
label variable necta "New England city and town area NECTA, 2000 (Source: MCDC)"

* manual correction:
* CBSA 31700 "Manchester-Nashua, NH Metropolitan Statistical Area" 
* is assigned to NECTA 71650 "Boston-Cambridge-Quincy, MA-NH Metropolitan NECTA" 
* instead of NECTA 74950 "Manchester, NH Metropolitan NECTA"
replace necta = 74950 if cbsa==31700
replace nectaname = "Manchester, NH Metropolitan NECTA" if cbsa==31700

* save
drop hus2k
sort necta cbsa
order necta cbsa
save temp/necta.dta, replace

* ------------------------------
* Metro Divisions to CBSA Correspondence 
* ------------------------------

* DATA SOURCE:
* Missouri Census Data Center (MCDC)
*
* WEBLINK:
* http://mcdc.missouri.edu/websas/geocorr2k.html
*
* LOCAL FILE LOCATION:
* rawdata/metrodivcbsa.dta 
*
* DESCRIPTION:
* Metro Divisions
* to Core Based Statistical Area (CBSA) code correspondence

* open raw data
use "rawdata/metrodivcbsa.dta", clear

* keep only areas with metro divisions
keep if ~missing(metrodiv)

* save
drop hus2k afact
save temp/metrodiv.dta, replace

* ------------------------------
* CBSA Population 
* ------------------------------

* DATA SOURCE:
* U.S. Census Bureau
*
* WEBLINK:
* http://www.census.gov/popest/data/historical/2000s/vintage_2009/metro.html
*
* LOCAL FILE LOCATION:
* rawdata/cbsa-est2009-01.dta

* use population data
use rawdata/cbsa-est2009-01.dta, clear
label variable cbsa "Core based Statistical Area CBSA, FIPS code"

* drop data on metro divisions
drop if ~missing(metrodiv)
sort cbsa
drop name metrodiv
label variable pop2009 "CBSA population, `year' (Source: Census)"

* keep only 2009 data
keep cbsa pop2009

* in logs
generate lpop2009 = log(pop2009)
label variable lpop2009 "log CBSA population, `year' (Source: Census)"

* save
save temp/population.dta, replace

* ------------------------------
* Hedonic Housing Prices 
* ------------------------------

* DATA SOURCE:
* U.S. Census Bureau, American Community Survey (ACS)
* provided by Minnesota Population Center, IPUMS-USA
*
* WEBLINK:
* https://usa.ipums.org/usa/
*
* VARIABLE IN RAW DATA:
* year datanum serial hhwt statefip metro metarea metaread puma 
* gq farm ownershp ownershpd rent rooms builtyr2 unitsstr 
* pernum perwt age bpl bpld labforce wkswork2 uhrswork incwage 
*
* LOCAL FILE LOCATION:
* rawdata/acs.dta

* open ACS raw data
use rawdata/acs.dta, clear

* only 2009 data
keep if year==2009

* drop group quarters (institutions), drop 2000 definition of families (e.g. may contain 54 members)
drop if gq==3 | gq==4 | gq==5

* drop farmhouses
drop if farm~=1 

* drop mobile homes, trailers, boats, tents, ...
drop if unitsstr==01 | unitsstr==02

* collapse to household level
foreach v of var * {
	local l`v' : variable label `v'
	if `"`l`v''"' == "" {
		local l`v' "`v'" 
	}
}
collapse (first) hhwt-incwage (count) hhmembers=hhwt, by(year datanum serial) 
foreach v of var * {
	label var `v' "`l`v''"
}
label var hhmembers "Number of household members in dataset"

* merge CBSA to PUMA
rename statefip state
sort state puma
merge m:1 state puma using temp/puma.dta, keep(match master)
tabulate puma if _merge==1 & metaread~=0
* note: PUMA 77777 (New Orleans, LA) is not merged
drop _merge
order serial hhwt state puma statepuma metro cbsa

* label CBSA
do temp/cbsalabel.do
label values cbsa cbsa
drop cbsaname

* drop if not in known metro area
drop if missing(cbsa)

* generate price vars
replace rent = . if rent==0
generate lrent = log(rent)

* top code number of rooms at 9 (max is 28 in ACS, 9 in PUMS)
replace rooms = 9 if rooms > 9
tabulate rooms, nolabel

* ACS 2009 labels "builtyr2"
label define builtyr2 01	"1939 or earlier", add
label define builtyr2 02	"1940-1949", add
label define builtyr2 03	"1950-1959", add
label define builtyr2 04	"1960-1969", add
label define builtyr2 05	"1970-1979", add
label define builtyr2 06	"1980-1989", add
label define builtyr2 07	"1990-1999", add
label define builtyr2 09	"2000-2004", add
label define builtyr2 10	"2005", add
label define builtyr2 11	"2006", add
label define builtyr2 12	"2007", add
label define builtyr2 13	"2008", add
label define builtyr2 14	"2009", add
label values builtyr2 builtyr2
tabulate builtyr2

* ACS 2009 labels "unitstr"
label define unitsstr 00	"N/A", add
label define unitsstr 01	"Mobile home or trailer", add	
label define unitsstr 02	"Boat, tent, van, other", add	
label define unitsstr 03	"1-family house, detached", add
label define unitsstr 04	"1-family house, attached", add
label define unitsstr 05	"2-family building", add	
label define unitsstr 06	"3-4 family building", add		
label define unitsstr 07	"5-9 family building", add		
label define unitsstr 08	"10-19 family building", add	
label define unitsstr 09	"20-49 family building", add	
label define unitsstr 10	"50+ family building", add		
label values unitsstr unitsstr
tabulate unitsstr

* define sample, rules out missing values in rent
generate samplecbsa = (~missing(cbsa) & ownershpd==22 & rent>0 & ~missing(rent))
generate samplepuma = (~missing(statepuma) & ownershpd==22 & rent>0 & ~missing(rent))

* hedonic regression with cbsa fixed effects
* reference groups are 4="4 rooms", 9="1990-1999", 3="1-family detached"
* note: xtreg cannot deal with weights within areas
reg lrent b4.rooms b9.builtyr2 b3.unitsstr i.cbsa [aw=hhwt] if samplecbsa
estimates store lrent_cbsa

* sample size for Table 4 footer
sum rent if e(sample)
codebook cbsa if e(sample)
codebook statepuma if e(sample)

* store cbsa fixed effects in data
levelsof cbsa if samplecbsa
generate lrentindexcbsa = .
foreach lev in `r(levels)' {
	replace lrentindexcbsa = _b[_cons]+_b[`lev'.cbsa] if cbsa==`lev'
}
generate rentindexcbsa = exp(lrentindexcbsa)

* hedonic regression with puma fixed effects
* note: puma id is not unique across states, use unique statepuma id
reg lrent b4.rooms b9.builtyr2 b3.unitsstr i.statepuma [aw=hhwt] if samplepuma
estimates store lrent_puma

* number of observations per area
bysort cbsa:      egen rentobscbsa = total(samplecbsa)
bysort statepuma: egen rentobspuma = total(samplepuma)

* weight of all observations per area
bysort cbsa:      egen renthhwtcbsa = total(hhwt*samplecbsa)
bysort statepuma: egen renthhwtpuma = total(hhwt*samplepuma)

* store puma fixed effects in data
levelsof statepuma if samplepuma
generate lrentindexpuma = .
foreach lev in `r(levels)' {
	replace lrentindexpuma = _b[_cons]+_b[`lev'.statepuma] if statepuma==`lev'
}
generate rentindexpuma = exp(lrentindexpuma)

* save estimation results: Table 4
estout * using "results/table4.txt", stats(r2 N N_g, fmt(%12.4f)) cells(b(star fmt(%9.4f)) se(fmt(%9.4f))) starlevels(* 0.10 ** 0.05 *** 0.01) margin legend replace

* labels
label variable lrentindexcbsa  "Log housing rent, monthly, cbsa hedonic price index, 2009 (Source: ACS)"
label variable rentindexcbsa   "Housing rent, monthly, cbsa hedonic price index, 2009 (Source: ACS)"
label variable rentobscbsa 	   "Number of observed rental prices in cbsa, 2009 (Source: ACS)"
label variable renthhwtcbsa    "Total household weights of observed prices in cbsa, 2009 (Source: ACS)"
label variable lrentindexpuma  "Log housing rent, monthly, puma hedonic price index, 2009 (Source: ACS)"
label variable rentindexpuma   "Housing rent, monthly, puma hedonic price index, 2009 (Source: ACS)"
label variable rentobspuma 	   "Number of observed rental prices in puma, 2009 (Source: ACS)"
label variable renthhwtpuma    "Total household weights of observed prices in puma, 2009 (Source: ACS)"
	
* only keep one obs per PUMA
bysort statepuma: egen seqpuma = seq() if ~missing(rentindexpuma)
keep if seqpuma==1

* standardize index to mean=1 across PUMA
sum rentindexpuma [aw=renthhwtpuma]
replace rentindexpuma = rentindexpuma/r(mean)
replace lrentindexpuma = log(rentindexpuma)		

* generate max PUMA price per cbsa
egen rentindexpumamax = max(rentindexpuma), by(cbsa)
label variable rentindexpumamax "Housing rent, monthly, puma with max per cbsa, 2009 (Source: acs)"

* top 10% of PUMA by price
egen pumarentpct10 = pctile(rentindexpuma), p(90) by(cbsa) 
generate pumatop10 = rentindexpuma >= pumarentpct10
egen temp = mean(rentindexpuma) if pumatop10==1, by(cbsa)
egen rentindexpumatop10 = max(temp), by(cbsa)
drop temp pumarentpct10 pumatop10
label variable rentindexpumatop10 "Housing rent, monthly, average of top 10% pumas per cbsa, 2009 (Source: acs)"

* save rent index for PUMA
keep puma state statepuma cbsa lrentindex* rentindex* rentindexpumamax rentindexpumatop10 rentobs* renthhwt*
order puma state statepuma cbsa lrentindex* rentindex* rentindexpumamax rentindexpumatop10 rentobs* renthhwt*
save temp/housepricepuma.dta, replace

* only keep one obs per CBSA
bysort cbsa: egen seqcbsa = seq() if ~missing(rentindexcbsa)
keep if seqcbsa==1

* standardize index to mean=1 across CBSA
sum rentindexcbsa [aw=renthhwtcbsa]
replace rentindexcbsa = rentindexcbsa/r(mean)
replace lrentindexcbsa = log(rentindexcbsa)		

* save rent index for cbsa
keep cbsa lrentindexcbsa rentindexcbsa rentindexpumamax rentindexpumatop10 rentobscbsa renthhwtcbsa
order cbsa lrentindexcbsa rentindexcbsa rentindexpumamax rentindexpumatop10 rentobscbsa renthhwtcbsa
save temp/housepricecbsa.dta, replace

* ------------------------------
* Cost of Living Index
* ------------------------------

* DATA SOURCE:
* The Council for Community and Economic Research (C2ER)
* Purchased Sep 13, 2010 under invoice number COLI-INTL09132010
*
* WEBLINK:
* http://www.coli.org/
*
* LOCAL FILE LOCATION:
* rawdata/coliq2200922008.dta


* note: we use 2008.Q2-2009.Q2 averages as this covers more
* cities. 2009 data misses e.g. Las Vegas, Milwaukee, ...

* open raw data
use rawdata/coliq2200922008.dta, clear

* CBSA codes
* note: C2ER reports CBSA and Metrodiv for divided cities
generate state = floor(accracode/100000000)
generate cbsametrodiv = floor((accracode-state*100000000)/1000)
drop if cbsametrodiv==88888 | cbsametrodiv==99999

* CBSA codes for metro divisions
rename cbsametrodiv metrodiv
merge m:1 metrodiv using "temp/metrodiv.dta", keep(match master)
codebook cbsa
generate ismetrodiv = (_merge==3)
drop _merge 
rename metrodiv cbsametrodiv
*drop cbsaname mdivname

* assign ACCRA code as CBSA code where no metro division is identified
replace cbsa = cbsametrodiv if missing(cbsa)

* manually change CBSA codes which differ from MCDC data
replace cbsa=32270 if cbsa==49220 /*Wisconsin Rapids-Marshfield WI Micro*/
replace cbsa=14600 if cbsa==42260 /*Sarasota-Bradenton-Venice FL Metro*/

* label CBSA
do temp/cbsalabel.do
label values cbsa cbsa

* sample size for Appendix B
* number of CBSA
codebook cbsa
* number of Metro divisions
codebook cbsametrodiv if ismetrodiv
* number of CBSA with metro divisions
codebook cbsa if ismetrodiv
tabulate cbsa if ismetrodiv

* average metropolitan divisions and multiple observations per CBSA
collapse (mean) price_composite price_grocery price_housing price_utilities price_transport price_health price_services, by(cbsa)
foreach item in composite grocery housing utilities transport health services {
	label var price_`item' "Local price index, `item', average 2008.Q2-2009.Q2 (Source: C2ER)"
	generate lprice_`item' = log(price_`item')
	label var lprice_`item' "Log local price index, `item', average 2008.Q2-2009.Q2 (Source: C2ER)"
}

* merge CBSA population from Census
merge m:1 cbsa using temp/population.dta, keep(master match)
drop _merge
order cbsa pop2009

* save
sort cbsa
save finaldata/costliving.dta, replace

* ------------------------------
*  Wage and skill from CPS 2009
* ------------------------------

* DATA SOURCE:
* Current Population Survey (CPS), 2009 merged outgoing rotation groups (MORG) 
* provided by National Bureau of Economic Research (NBER)
*
* WEBLINK:
* http://www.nber.org/morg/annual/morg09.dta
*
* LOCAL FILE LOCATION:
* rawdata/morg09.dta

* open CPS raw data
use rawdata/morg09.dta, clear

* total number of observations in 2009 CPS
describe, short
 
* create person identifier within household
bysort hhid: generate pid = _n
order minsamp intmonth hhid pid

* weekly wage for full time workers
gen wage=earnwke if ftpt94==2 & uhourse>=36 & uhourse<=60
label var wage "Weekly wage full time workers, `year' (Source: CPS)"

* drop lowest 0.5% of observations to deal with obvious outliers
replace wage = . if wage <= 0
centile wage, centile(0.5)
local wagemin = r(c_1)
generate wagemin = `wagemin'
replace wage = . if wage < wagemin
sum wage, detail

* log wage
gen lwage = log(wage)
label var lwage "= log(wage)"

* top code flags for wage
egen wagemax = max(wage)
label var wagemax "top code for wage"
egen lwagemax = max(lwage)
label var lwagemax "top code for lwage"
generate wagetop = (wage==wagemax) if ~missing(wage)
label var wagetop "1 = wage is top coded, 0 otherwise"

* labels citizenship status
label define prcitshp 1 "Native, born in US" 2 "Native, born in Puerto Rico or US Outlying Area" 3 "Native, born abroad of American Parent(s)" 4 "Foreign born, US citizen by naturalization" 5 "Foreign born, Not a citizen of the US"
label values prcitshp prcitshp

* only keep relevant variables
keep hhid pid year stfips cbsafips age sex race grade92 prcitshp ind02 dind02 occ00 docc00 earnwt wage lwage wagemax lwagemax wagetop

* only keep observations with wage data
keep if ~missing(wage)

* merge CBSA codes (2000 definitions)
* note: cbsafips in CPS is NECTA for New England and CBSA elsewhere
replace cbsafips = . if cbsafips==0
generate necta = cbsafips
merge m:1 necta using temp/necta.dta, keep(match master) keepusing(cbsa)
drop _merge
replace cbsa = cbsafips if missing(cbsa)
drop cbsafips
order hhid pid stfips 

* label cbsa
do temp/cbsalabel.do
label values cbsa cbsa

* merge CBSA population from Census
* note: 7 small areas in CPS data not found in Census data:
* 22460 (Florence, AL), 42260 (Sarasota-Bradenton-Venice, FL), 46940, 72850, 74500, 77350, 78700
* dropping 698 individuals
merge m:1 cbsa using temp/population.dta, keep(master match)
drop _merge

* merge CBSA housing price
* note: 2 additional small areas are not merged: 36780, 41540
* dropping 142 individuals
merge m:1 cbsa using temp/housepricecbsa.dta, keep(master match)
drop _merge

* Appendix B, Table 3
egen seq = seq() if ~missing(cbsa), by(cbsa) 
gsort -pop2009
codebook cbsa pop2009 if seq==1 & pop2009>100000 & ~missing(rentindexcbsa)
list cbsa pop2009 if seq==1 & pop2009>100000 & ~missing(rentindexcbsa), table
browse cbsa pop2009 if seq==1 & pop2009>100000 & ~missing(rentindexcbsa)
drop seq

* Appendix B, Table 5
egen seq = seq() if ~missing(cbsa), by(cbsa) 
gsort -rentindexcbsa
codebook cbsa if seq==1 & pop2009>100000 & ~missing(rentindexcbsa)
list cbsa pop2009 rentindexcbsa if seq==1 & pop2009>100000 & ~missing(rentindexcbsa), table
browse cbsa pop2009 rentindexcbsa if seq==1 & pop2009>100000 & ~missing(rentindexcbsa)
drop seq

* merge C2ER cost of living index
* matched 181 CBSA, no major CBSA missing
* dropping 7081 individuals
merge m:1 cbsa using finaldata/costliving.dta, keep(master match)
codebook cbsa if _merge==3
tabulate cbsa if _merge==1
drop _merge

* baseline wage-based skill measure
* Cobb-Douglas utility, ACS hedonic housing price index
local a = 0.24
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility1 = wage/(rentindexcbsa^(`a')*`K')
label var utility1 "Skill: cbsa rentindex (ACS 2009)"
generate lutility1 = log(utility1)
label var lutility1 "Skill: Cobb-Douglas, cbsa rentindex (ACS 2009)"
* top code flags
generate utility1top = wagetop
label var utility1top "1 = utility1 is top coded, 0 otherwise"

* alternative skill measure
* Cobb-Douglas utility, ACS hedonic housing price index, price of top 10% puma
local a = 0.24
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility2 = wage/(rentindexpumatop10^(`a')*`K')
label var utility2 "Skill: avearge of top 10% PUMA area rentindex (ACS 2009)"
generate lutility2 = log(utility2)
label var lutility2 "Skill: avearge of top 10% PUMA area rentindex (ACS 2009)"
* top code flags
generate utility2top = wagetop
label var utility2top "1 = utility2 is top coded, 0 otherwise"

* alternative skill measure
* Stone-Geary utility, ACS hedonic housing price index
local a = 0.224 
local h = 27.7 
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility4 = 1/`K'*(wage/rentindexcbsa-`h')* rentindexcbsa ^(1-`a')
label var utility4 "Skill: cbsa rentindex (ACS 2009)"
generate lutility4 = log(utility4)
label var lutility4 "Skill: Stone-Geary, cbsa rentindex (ACS 2009)"
* top code flags
generate utility4top = wagetop
label var utility4top "1 = utility4 is top coded, 0 otherwise"

* alternative skill measure
* Stone-Geary utility (h=250), ACS hedonic housing price index
local a = 0.224 
local h = 250 
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility5 = 1/`K'*(wage/rentindexcbsa-`h')* rentindexcbsa ^(1-`a')
label var utility5 "Skill: cbsa rentindex (ACS 2009)"
generate lutility5 = log(utility5)
label var lutility5 "Skill: Stone-Geary (h=250), cbsa rentindex (ACS 2009)"
* top code flags
generate utility5top = wagetop
label var utility5top "1 = utility5 is top coded, 0 otherwise"

* alternative skill measure
* Cobb-Douglas, C2ER cost of living index
generate utility6 = wage/(price_grocery^0.1249*price_housing^0.2918*price_utilities^0.0998*price_transport^0.111*price_health^0.0406*price_services^0.3319)
label var utility6 "Skill: cbsa price composite, own aggregation (C2ER 2009)"
generate lutility6 = log(utility6)
label var lutility6 "Skill: cbsa price composite, own aggregation (C2ER 2009)"
* top code flags
generate utility6top = wagetop
label var utility6top "1 = utility6 is top coded, 0 otherwise"

* drop C2ER cost of living data, because data is not public
foreach item in composite grocery housing utilities transport health services {
	replace price_`item' = -1
	replace lprice_`item' = -1
}

* education in 5 categories
generate gradecat = .
replace gradecat = 1 if grade92 <= 38
replace gradecat = 2 if grade92 == 39
replace gradecat = 3 if grade92 >= 40 & grade92 <= 42
replace gradecat = 4 if grade92 == 43
replace gradecat = 5 if grade92 >= 44
label variable gradecat "Highest grade completed in 5 categories"
label define gradecat 1 "No high school" 2 "High school degree" 3 "Some College" 4 "Bachelor" 5 "Master or more"
label values gradecat gradecat
tabulate gradecat

* occupations in 5 categories from occupations ranked by median wage
egen wageoccmed = median(wage), by(occ00)
generate occcat = .
centile wageoccmed, centile(5 25 75 95)
replace occcat = 1 if wageoccmed <= r(c_1)
replace occcat = 2 if wageoccmed > r(c_1) & wageoccmed <= r(c_2)
replace occcat = 3 if wageoccmed > r(c_2) & wageoccmed <= r(c_3)
replace occcat = 4 if wageoccmed > r(c_3) & wageoccmed <= r(c_4)
replace occcat = 5 if wageoccmed > r(c_4)
label variable occcat "Occupation in 5 categories"
label define occcat 1 "low skill occupations" 3 "middle skill occupations" 5 "high skill occupations"
label values occcat occcat
tabulate occcat

* industry in 5 categories from industries ranked by median wage
egen wageindmed = median(wage), by(ind)
generate indcat = .
centile wageindmed, centile(5 25 75 95)
replace indcat = 1 if wageindmed <= r(c_1)
replace indcat = 2 if wageindmed > r(c_1) & wageindmed <= r(c_2)
replace indcat = 3 if wageindmed > r(c_2) & wageindmed <= r(c_3)
replace indcat = 4 if wageindmed > r(c_3) & wageindmed <= r(c_4)
replace indcat = 5 if wageindmed > r(c_4)
label variable indcat "Indsutry in 5 categories"
label define indcat 1 "low skill occupations" 3 "middle skill occupations" 5 "high skill occupations"
label values indcat indcat
tabulate indcat

* race
generate myrace = .
replace myrace = 1 if race ==  1 //White  
replace myrace = 2 if race ==  2 //Black
replace myrace = 4 if race ==  3 //American Indian
replace myrace = 3 if race ==  4 //Asian only
replace myrace = 4 if race ==  5 //Hawaiian/Pacific Islander only
replace myrace = 4 if race ==  6 //White-Black
replace myrace = 4 if race ==  7 //White-AI
replace myrace = 4 if race ==  8 //White-Asian
replace myrace = 4 if race ==  9 //White-Hawaiian
replace myrace = 4 if race == 10 //Black-AI
replace myrace = 4 if race == 11 //Black-Asian
replace myrace = 4 if race == 12 //Black-HP
replace myrace = 4 if race == 13 //AI-Asian
replace myrace = 4 if race == 14 //Asian-HP
replace myrace = 4 if race == 15 //W-B-AI
replace myrace = 4 if race == 16 //W-B-A
replace myrace = 4 if race == 17 //W-AI-A
replace myrace = 4 if race == 18 //W-A-HP
replace myrace = 4 if race == 19 //W-B-AI-A
replace myrace = 4 if race == 20 //2 or 3 Races
replace myrace = 4 if race == 21 //4 or 5 Races
label var myrace "Race in 4 categories"
label define myrace 1 "white" 2 "black" 3 "asian only" 4 "other"
label values myrace myrace

* age
generate age2 = age^2
label var age2 "Age^2"

* foreign: Foreign born, Not a citizen of the US
generate foreign = prcitshp>4 & ~missing(prcitshp)
label var foreign "Citizenship dummy, 1 = foreign born, 0 = native"
label define foreign  0 "native" 1 "foreign born"
label values foreign foreign

* save
order year
save finaldata/skillcps.dta, replace

* ------------------------------
*  Wage and skill from ACS 2009
* ------------------------------

* U.S. Census Bureau, American Community Survey (ACS)
* provided by Minnesota Population Center, IPUMS-USA
*
* WEBLINK:
* https://usa.ipums.org/usa/
*
* VARIABLE IN RAW DATA:
* year datanum serial hhwt statefip metro metarea metaread puma 
* gq farm ownershp ownershpd rent rooms builtyr2 unitsstr 
* pernum perwt age bpl bpld labforce wkswork2 uhrswork incwage 
*
* LOCAL FILE LOCATION:
* rawdata/acs.dta

* open ACS raw data
use `datadir'rawdata/acs.dta, clear

* id names as in cps
rename serial hhid
rename pernum pid
order year hhid pid
	
* only 2009 data
keep if year==2009

* yearly wage for full time workers, full year workers
replace incwage = . if incwage==999999
gen wage = .
replace wage = incwage/48.5 if labforce==2 & wkswork2==5 & uhrswork>=36 & uhrswork<=60 // 48-49 weeks
replace wage = incwage/51 if labforce==2 & wkswork2==6 & uhrswork>=36 & uhrswork<=60 // 50-52 weeks	
replace wage = . if wage <= 0
label var wage "Weekly wage full-time, full-year workers, `year' (Source: ACS)"

* drop lowest 0.1% of observations to deal with obvious outliers
egen wagemin = pctile(wage), p(0.1) 
replace wage = . if wage <= wagemin
replace wage = wagemin if wage < wagemin
sum wage, detail
	
* log wage	
gen lwage = log(wage)
label var lwage "= log(wage)"
	
* weight, same variable name as CPS
generate earnwt = perwt/100
label var earnwt "Person weight, =perwt/100"
	
* birthplace
generate birthplace = 1 if bpl<=99
replace birthplace = 2 if bpl>=100 & bpl<150
replace birthplace = 3 if bpl>=150
label var birthplace "Birthplace" 
label define birthplace 1 "Born in US" 2 "Born in Puerto Rico or US Outlying Area" 3 "Born abroad" 

* merge CBSA to PUMA
* note: we could also get CBSA from metaread which leads to different assignments for some workers (~18%)
* for consistency with the price calculations on PUMA level, we don't do this in the final version
* results in working paper version use assignment from metaread
* all results are practically identical for either assignment
rename statefip state
sort state puma
merge m:1 state puma using temp/puma.dta, keep(match master)
tabulate puma if _merge==1 & metaread~=0
* note: PUMA 77777 (New Orleans, LA) is not merged
drop _merge
order hhid pid hhwt state puma statepuma metro cbsa

* label cbsa
do temp/cbsalabel.do
label values cbsa cbsa
drop cbsaname

* only use observations reported from metroareas
* note: not whole PUMA may be part of CBSA
replace cbsa = . if metro <=1

* drop if not in identified metro area
drop if missing(cbsa)

* merge CBSA population from Census
merge m:1 cbsa using temp/population.dta, keep(master match)
drop _merge

* merge CBSA housing price
merge m:1 cbsa using temp/housepricecbsa.dta, keep(master match)
drop _merge

* merge PUMA housing price
merge m:1 state puma using temp/housepricepuma.dta, keep(master match)
drop _merge

* drop observations with missing wage
keep if ~missing(wage)

* baseline wage-based skill measure
* Cobb-Douglas utility, ACS hedonic housing price index
local a = 0.24
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility1 = wage/(rentindexcbsa^(`a')*`K')
label var utility1 "Skill: cbsa rentindex (ACS 2009)"
generate lutility1 = log(utility1)
label var lutility1 "Skill: Cobb-Douglas, cbsa rentindex (ACS 2009)"

* alternative skill measure
* Cobb-Douglas utility, ACS hedonic housing price index, price of top 10% puma
local a = 0.24
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility2 = wage/(rentindexpumatop10^(`a')*`K')
label var utility2 "Skill: avearge of top 10% PUMA area rentindex (ACS 2009)"
generate lutility2 = log(utility2)
label var lutility2 "Skill: avearge of top 10% PUMA area rentindex (ACS 2009)"

* alternative skill measure
* Cobb-Douglas utility, ACS hedonic housing price index, price of own puma
local a = 0.24
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility3 = wage/(rentindexpuma^(`a')*`K')
label var utility3 "Skill: puma rentindex (ACS 2009)"
generate lutility3 = log(utility3)
label var lutility3 "Skill: puma rentindex (ACS 2009)"

* alternative skill measure
* Stone-Geary utility, ACS hedonic housing price index
local a = 0.224 
local h = 27.7 
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility4 = 1/`K'*(wage/rentindexcbsa-`h')* rentindexcbsa ^(1-`a')
label var utility4 "Skill: cbsa rentindex (ACS 2009)"
generate lutility4 = log(utility4)
label var lutility4 "Skill: Stone-Geary, cbsa rentindex (ACS 2009)"

* alternative skill measure
* Stone-Geary utility (h=250), ACS hedonic housing price index
local a = 0.224 
local h = 250 
local K = 1/(`a'^`a'*(1-`a')^(1-`a'))
generate utility5 = 1/`K'*(wage/rentindexcbsa-`h')* rentindexcbsa ^(1-`a')
label var utility5 "Skill: cbsa rentindex (ACS 2009)"
generate lutility5 = log(utility5)
label var lutility5 "Skill: Stone-Geary (h=250), cbsa rentindex (ACS 2009)"

* save
order year
save finaldata/skillacs.dta, replace

* ------------------------------
* Consumer Expenditure Survey 
* ------------------------------

* DATA SOURCE:
* U.S. Bureau of Labor Statistics, Consumer Expenditure Survey (CEX)
* Public-use microdata 2011
*
* WEBLINK:
* http://www.bls.gov/cex/pumdhome.htm
*
* LOCAL FILE LOCATION:
* rawdata/fmli111x.dta

* open CEX raw data
use rawdata/fmli111x.dta, clear

* assign cbsa codes
* 35620 New York-Northern New Jersey-Long Island, NY-NJ-PA Metropolitan Statistical
* 37980 Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area
* 14460 Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area
* 16980 Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area
* 19820 Detroit-Warren-Livonia, MI Metropolitan Statistical Area
* 17460 Cleveland-Elyria-Mentor, OH Metropolitan Statistical Area
* 33460 Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area
* 47900 Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area
* 12580 Baltimore-Towson, MD Metropolitan Statistical Area
* 19100 Dallas-Fort Worth-Arlington, TX Metropolitan Statistical Area
* 26420 Houston-Sugar Land-Baytown, TX Metropolitan Statistical Area
* 12060 Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area
* 33100 Miami-Fort Lauderdale-Pompano Beach, FL Metropolitan Statistical Area  
* 31100 Los Angeles-Long Beach-Santa Ana, CA Metropolitan Statistical Area
* 41860 San Francisco-Oakland-Fremont, CA Metropolitan Statistical Area
* 42660 Seattle-Tacoma-Bellevue, WA Metropolitan Statistical Area
* 41740 San Diego-Carlsbad-San Marcos, CA Metropolitan Statistical Area    
* 38060 Phoenix-Mesa-Scottsdale, AZ Metropolitan Statistical Area 
generate cbsa = .
replace cbsa = 35620 if psu == "1109"
replace cbsa = 35620 if psu == "1110"
replace cbsa = 35620 if psu == "1111"
replace cbsa = 37980 if psu == "1102"
replace cbsa = 14460 if psu == "1103"
replace cbsa = 16980 if psu == "1207"
replace cbsa = 19820 if psu == "1208"
replace cbsa = 17460 if psu == "1210"
replace cbsa = 33460 if psu == "1211"
replace cbsa = 47900 if psu == "1312"
replace cbsa = 12580 if psu == "1313"
replace cbsa = 19100 if psu == "1316"
replace cbsa = 26420 if psu == "1318"
replace cbsa = 12060 if psu == "1319"
replace cbsa = 33100 if psu == "1320"
replace cbsa = 31100 if psu == "1419"
replace cbsa = 31100 if psu == "1420"
replace cbsa = 41860 if psu == "1422"
replace cbsa = 42660 if psu == "1423"
replace cbsa = 41740 if psu == "1424"
replace cbsa = 38060 if psu == "1429"
label variable cbsa "Core based statistical area, metropolitan and micropolitan [MCDC/Geocorr2K]"

* label CBSA
do temp/cbsalabel.do
label values cbsa cbsa

* merge CBSA houseprice
merge m:1 cbsa using temp/housepricecbsa.dta, keep(match master)
drop _merge

* expenditures current quarter seem to be monthly values
* reported values in standard tables is "Average annual expenditures" = $49,705
sum totexpcq

* weekly expenditures
generate wktotexp = totexpcq*12/52
label var wktotexp "Weekly total expenditures (CEX 2011)"
generate wkshelt = sheltcq*12/52
label var wkshelt "Weekly expenditures on shelter (CEX 2011)"

* weekly income
generate wkinc = fincbtax/52
label var wkinc "Weekly total income before tax (CEX 2011)"

* expenditure share of housing
sum totexpcq sheltcq
generate sheltcq_shr = wkshelt/wktotexp if wktotexp>0 & wkshelt>0
label var sheltcq_shr "Expenditure share of shelter (CEX 2011)"
sum sheltcq_shr
tabstat sheltcq_shr, by(inclass)

* save
keep newid finlwt21 cbsa wktotexp wkshelt wkinc sheltcq_shr lrentindexcbsa rentindexcbsa rentindexpumamax rentindexpumatop10 rentobscbsa renthhwtcbsa
order newid finlwt21 cbsa wktotexp wkshelt wkinc sheltcq_shr lrentindexcbsa rentindexcbsa rentindexpumamax rentindexpumatop10 rentobscbsa renthhwtcbsa
save finaldata/cex.dta, replace
