* PROJECT:
* Jan Eeckhout, Roberto Pinheiro, Kurt Schmidheiny
* "Spatial Sorting"
* Forthcoming 2014 in the Journal of Political Economy
*
* FILE: 
* section5.do
*
* DESCRIPTION:
* produce figures 2 and 3 in section 5
*
* VERSION: 
* Jan-13-2014

clear all

* open skill data from CPS
use finaldata/skillcps.dta

* sample,  keep only observations
* - identified CBSA 
* - with assigned CBSA housing price
* - cbsa with population > 100000
keep if ~missing(cbsa) & ~missing(rentindexcbsa) & (pop2009>=100000 & ~missing(pop2009))

* define city groups
generate group = .
replace group = 1 if pop2009<=1000000 & pop2009>100000 & ~missing(pop2009)
replace group = 2 if pop2009>2500000 & ~missing(pop2009)
label define group 1 "pop < 1m" 2 "pop > 2.5m"
generate group1 = (group==1) if ~missing(group)
generate group2 = (group==2) if ~missing(group)

* ------------------------------------------------------------
* Section 5.1
* ------------------------------------------------------------

* number of workers and CBSA in sample
sum wage
codebook cbsa

* number of top coded observations
sum wagetop
tabulate wagetop

* ACS see data.do, Table 4

* ------------------------------------------------------------
* Section 5.2
* ------------------------------------------------------------

* simple t-test
* note: ignores right censoring and weights
ttest lwage, by(group)

* weighted censored regression
* note: use cnreg because "tobit" does not allow for variable truncation point
cnreg lwage group [aw=earnwt], censored(wagetop) robust

* test 10th and 90th quantile of log wage, weighted
foreach quant in 0.1 0.9 {
	qreg lwage group2 [aw=earnwt], q(`quant')
}

* median regression of log wage on CBSA population
qreg lwage lpop2009 [aw=earnwt], q(0.5)

* ------------------------------------------------------------
* Section 5.3
* ------------------------------------------------------------

* median regression of log CBSA housing price on CBSA population
* note: large cities are implicitly weighted more by using individual worker data
qreg lrentindexcbsa lpop2009 [aw=earnwt], q(0.5)

* test 10th and 90th quantile of log utility, weighted
foreach quant in 0.1 0.9 {
	qreg lutility1 group2 [aw=earnwt], q(`quant')
}

* ------------------------------------------------------------
* Figure 2 left
* ------------------------------------------------------------

* estimate quantile regressions
foreach quant in 0.1 0.25 0.5 0.75 0.9 {
	qreg lwage lpop2009 [aw=earnwt], q(`quant')
	local quantpct = 100*`quant'
	estimates store skill_q`quantpct'
	predict lutility_q`quantpct' if e(sample), xb
	local slope`quantpct' = string(_b[lpop2009],"%9.3f")
	local se`quantpct' = string(_se[lpop2009],"%9.3f")
	local p`quantpct' = string(ttail(e(df_r), abs(_b[lpop2009]/_se[lpop2009])),"%9.1f")
	if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.005 {
		local star`quantpct' = "***"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.025 {
		local star`quantpct' = "**"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.05 {
		local star`quantpct' = "*"
	}
	else {
		local star`quantpct' = ""
	}
}

* plot predicted quantiles
egen cityobs = seq(), by(cbsa)
sort lpop2009
#delimit ;
twoway 
	line lutility_q10 lpop2009 if cityobs==1, lpattern(dash_dot) lcolor(black) legend(label(1 "10th percentile")) 
	||
	line lutility_q25 lpop2009 if cityobs==1, lpattern(dash) lcolor(black) legend(label(2 "25th percentile")) 
	||
	line lutility_q50 lpop2009 if cityobs==1, lpattern(solid) lcolor(black) legend(label(3 "50th")) 
	||
	line lutility_q75 lpop2009 if cityobs==1, lpattern(dash) lcolor(black) legend(label(4 "25th/75th")) 
	||
	line lutility_q90 lpop2009 if cityobs==1, lpattern(dash_dot) lcolor(black) legend(label(5 "10th/90th percentile")) 
	, xtitle(log population) ytitle("log wage") scheme(s1color) legend(region(lstyle(none))) legend(order(3 4 5)) legend(rows(1))
	xsize(5.5) ysize(4.3) scale(1)
	note(
		"10th percentile: slope = `slope10'`star10' (`se10')" 
		"90th percentile: slope = `slope90'`star90' (`se90')" 
	);
#delimit cr
drop lutility_q* cityobs

* save graph
graph export "results/figure_2_left.pdf", replace
graph export "results/figure_2_left.eps", replace

* ------------------------------------------------------------
* Estimate Figure 2 right
* ------------------------------------------------------------

* plot all quantiles
qreg lwage lpop2009 [aw=earnwt]
grqreg lwage lpop2009 [aw=earnwt], ci save(temp/figure_2_right.dta)

* results are stored to draw nicely at the end

* ------------------------------------------------------------
* Figure 3 left
* ------------------------------------------------------------

* estimate quantile regressions
foreach quant in 0.1 0.25 0.5 0.75 0.9 {
	qreg lutility1 lpop2009 [aw=earnwt], q(`quant')
	local quantpct = 100*`quant'
	estimates store skill_q`quantpct'
	predict lutility_q`quantpct' if e(sample), xb
	local slope`quantpct' = string(_b[lpop2009],"%9.3f")
	local se`quantpct' = string(_se[lpop2009],"%9.3f")
	local p`quantpct' = string(ttail(e(df_r), abs(_b[lpop2009]/_se[lpop2009])),"%9.1f")
	if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.005 {
		local star`quantpct' = "***"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.025 {
		local star`quantpct' = "**"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.05 {
		local star`quantpct' = "*"
	}
	else {
		local star`quantpct' = ""
	}

}

* plot predicted quantiles
egen cityobs = seq(), by(cbsa)
sort lpop2009
#delimit ;
twoway 
	line lutility_q10 lpop2009 if cityobs==1, lpattern(dash_dot) lcolor(black) legend(label(1 "10th percentile")) 
	||
	line lutility_q25 lpop2009 if cityobs==1, lpattern(dash) lcolor(black) legend(label(2 "25th percentile")) 
	||
	line lutility_q50 lpop2009 if cityobs==1, lpattern(solid) lcolor(black) legend(label(3 "50th")) 
	||
	line lutility_q75 lpop2009 if cityobs==1, lpattern(dash) lcolor(black) legend(label(4 "25th/75th")) 
	||
	line lutility_q90 lpop2009 if cityobs==1, lpattern(dash_dot) lcolor(black) legend(label(5 "10th/90th percentile")) 
	, xtitle(log population) ytitle("skill (log utility)") scheme(s1color) legend(region(lstyle(none))) legend(order(3 4 5)) legend(rows(1))
	xsize(5.5) ysize(4.3) scale(1)
	note(
		"10th percentile: slope = `slope10'`star10' (`se10')" 
		"90th percentile: slope = `slope90'`star90' (`se90')" 
	);
#delimit cr
drop lutility_q* cityobs

* save graph
graph export "results/figure_3_left.pdf", replace
graph export "results/figure_3_left.eps", replace

* ------------------------------------------------------------
* Estimate Figure 3 right
* ------------------------------------------------------------

* plot all quantiles
qreg lutility1 lpop2009 [aw=earnwt]
grqreg lutility1 lpop2009 [aw=earnwt], ci save(temp/figure_3_right.dta)

* results are stored to draw nicely at the end

* ------------------------------------------------------------
* Draw Figure 2 right
* ------------------------------------------------------------

use temp/figure_2_right.dta, clear
#delimit ;
twoway 
	rarea lpop2009_cihi lpop2009_cilo qtile, lpattern(none) color(gs14) legend(label(1 "95% confidence bounds")) 
	||
	line lpop2009 qtile, lpattern(solid) lcolor(black) legend(label(2 "slope coefficient")) 
	, xtitle("wage quantile") ytitle("slope of log population") 
	scheme(s1color) legend(region(lstyle(none))) legend(order(2 1)) legend(rows(1))
	yline(0, lpattern(solid))
	xsize(5.50) ysize(4.3) scale(1)
	note(
		" " 
		" " 
	);
#delimit cr

* save graph
graph export "results/figure_2_right.pdf", replace
graph export "results/figure_2_right.eps", replace

* ------------------------------------------------------------
* Draw Figure 3 right
* ------------------------------------------------------------

use temp/figure_3_right.dta, clear
#delimit ;
twoway 
	rarea lpop2009_cihi lpop2009_cilo qtile, lpattern(none) color(gs14) legend(label(1 "95% confidence bounds")) 
	||
	line lpop2009 qtile, lpattern(solid) lcolor(black) legend(label(2 "slope coefficient")) 
	, xtitle("skill quantile") ytitle("slope of log population") 
	scheme(s1color) legend(region(lstyle(none))) legend(order(2 1)) legend(rows(1))
	yline(0, lpattern(solid))
	xsize(5.50) ysize(4.3) scale(1)
	note(
		" " 
		" " 
	);
#delimit cr

* save graph
graph export "results/figure_3_right.pdf", replace
graph export "results/figure_3_right.eps", replace
